@@ -6,6 +6,7 @@ if platform.system() != "Windows":
     # This platform is not supported, we don't want to crash on import
     # This test will be skipped anyway.
     import jax.numpy as jnp
+    from jax import random
     from flax.serialization import msgpack_restore, msgpack_serialize
     from safetensors import safe_open
     from safetensors.flax import load_file, save_file
@@ -15,11 +16,11 @@ if platform.system() != "Windows":
 @unittest.skipIf(platform.system() == "Windows", "Flax is not available on Windows")
 class LoadTestCase(unittest.TestCase):
     def setUp(self):
+        key = random.key(0)
         data = {
-            "test": jnp.zeros((1024, 1024), dtype=jnp.float32),
-            "test2": jnp.zeros((1024, 1024), dtype=jnp.float32),
-            "test3": jnp.zeros((1024, 1024), dtype=jnp.float32),
-            "test4": jnp.zeros((1024, 1024), dtype=jnp.bfloat16),
+            "test": random.normal(key, (1024, 1024), dtype=jnp.float32),
+            "test2": random.normal(key, (1024, 1024), dtype=jnp.float16),
+            "test3": random.normal(key, (1024, 1024), dtype=jnp.bfloat16),
         }
         self.flax_filename = "./tests/data/flax_load.msgpack"
         self.sf_filename = "./tests/data/flax_load.safetensors"
