@@ -1,6 +1,7 @@
 //! Module handling lazy loading via iterating on slices on the original buffer.
+use crate::lib::{String, ToString, Vec};
 use crate::tensor::TensorView;
-use std::ops::{
+use core::ops::{
     Bound, Range, RangeBounds, RangeFrom, RangeFull, RangeInclusive, RangeTo, RangeToInclusive,
 };
 
@@ -9,22 +10,54 @@ use std::ops::{
 pub enum InvalidSlice {
     /// When the client asked for more slices than the tensors has dimensions
     TooManySlices,
+    /// When the client asked for a slice that exceeds the allowed bounds
+    SliceOutOfRange {
+        /// The rank of the dimension that has the out of bounds
+        dim_index: usize,
+        /// The problematic value
+        asked: usize,
+        /// The dimension size we shouldn't go over.
+        dim_size: usize,
+    },
 }
 
 #[derive(Debug, Clone)]
 /// Generic structure used to index a slice of the tensor
 pub enum TensorIndexer {
-    //Select(usize),
+    /// This is selecting an entire dimension
+    Select(usize),
     /// This is a regular slice, purely indexing a chunk of the tensor
     Narrow(Bound<usize>, Bound<usize>),
     //IndexSelect(Tensor),
 }
 
-// impl From<usize> for TensorIndexer {
-//     fn from(index: usize) -> Self {
-//         TensorIndexer::Select(index)
-//     }
-// }
+fn display_bound(bound: &Bound<usize>) -> String {
+    match bound {
+        Bound::Unbounded => "".to_string(),
+        Bound::Excluded(n) => format!("{n}"),
+        Bound::Included(n) => format!("{n}"),
+    }
+}
+
+/// Intended for Python users mostly or at least for its conventions
+impl core::fmt::Display for TensorIndexer {
+    fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
+        match self {
+            TensorIndexer::Select(n) => {
+                write!(f, "{n}")
+            }
+            TensorIndexer::Narrow(left, right) => {
+                write!(f, "{}:{}", display_bound(left), display_bound(right))
+            }
+        }
+    }
+}
+
+impl From<usize> for TensorIndexer {
+    fn from(index: usize) -> Self {
+        TensorIndexer::Select(index)
+    }
+}
 
 // impl From<&[usize]> for TensorIndexer {
 //     fn from(index: &[usize]) -> Self {
@@ -44,7 +77,7 @@ macro_rules! impl_from_range {
     ($range_type:ty) => {
         impl From<$range_type> for TensorIndexer {
             fn from(range: $range_type) -> Self {
-                use std::ops::Bound::*;
+                use core::ops::Bound::*;
 
                 let start = match range.start_bound() {
                     Included(idx) => Included(*idx),
@@ -249,8 +282,18 @@ impl<'data> SliceIterator<'data> {
                     TensorIndexer::Narrow(Bound::Excluded(s), Bound::Included(stop)) => {
                         (*s + 1, *stop + 1)
                     }
+                    TensorIndexer::Select(s) => (*s, *s + 1),
                 };
-                newshape.push(stop - start);
+                if start >= shape && stop > shape {
+                    return Err(InvalidSlice::SliceOutOfRange {
+                        dim_index: i,
+                        asked: stop.saturating_sub(1),
+                        dim_size: shape,
+                    });
+                }
+                if let TensorIndexer::Narrow(..) = slice {
+                    newshape.push(stop - start);
+                }
                 if indices.is_empty() {
                     if start == 0 && stop == shape {
                         // We haven't started to slice yet, just increase the span
@@ -487,4 +530,47 @@ mod tests {
         assert_eq!(iterator.next(), Some(&data[16..24]));
         assert_eq!(iterator.next(), None);
     }
+
+    #[test]
+    fn test_slice_select() {
+        let data: Vec<u8> = vec![0.0f32, 1.0, 2.0, 3.0, 4.0, 5.0]
+            .into_iter()
+            .flat_map(|f| f.to_le_bytes())
+            .collect();
+
+        let attn_0 = TensorView::new(Dtype::F32, vec![2, 3], &data).unwrap();
+
+        let mut iterator = SliceIterator::new(
+            &attn_0,
+            &[
+                TensorIndexer::Select(1),
+                TensorIndexer::Narrow(Bound::Included(1), Bound::Excluded(3)),
+            ],
+        )
+        .unwrap();
+        assert_eq!(iterator.next(), Some(&data[16..24]));
+        assert_eq!(iterator.next(), None);
+
+        let mut iterator = SliceIterator::new(
+            &attn_0,
+            &[
+                TensorIndexer::Select(0),
+                TensorIndexer::Narrow(Bound::Included(1), Bound::Excluded(3)),
+            ],
+        )
+        .unwrap();
+        assert_eq!(iterator.next(), Some(&data[4..12]));
+        assert_eq!(iterator.next(), None);
+
+        let mut iterator = SliceIterator::new(
+            &attn_0,
+            &[
+                TensorIndexer::Narrow(Bound::Included(1), Bound::Excluded(2)),
+                TensorIndexer::Select(0),
+            ],
+        )
+        .unwrap();
+        assert_eq!(iterator.next(), Some(&data[12..16]));
+        assert_eq!(iterator.next(), None);
+    }
 }
